Index: third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp |
diff --git a/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp b/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp |
index 898e54807f2c45f42e1898c63a7d5ba1e10b2d66..9b5d7441f068f32f5e388e98b84f898c26c8785e 100644 |
--- a/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp |
+++ b/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp |
@@ -1117,16 +1117,16 @@ void GraphicsLayer::setScrollableArea(ScrollableArea* scrollableArea, |
void GraphicsLayer::didScroll() { |
if (m_scrollableArea) { |
- DoublePoint newPosition = |
- -m_scrollableArea->scrollOrigin() + |
- toDoubleSize(m_layer->layer()->scrollPositionDouble()); |
+ ScrollOffset newOffset = |
+ toFloatSize(m_layer->layer()->scrollPositionDouble() - |
+ m_scrollableArea->scrollOrigin()); |
- // FrameView::setScrollPosition() doesn't work for compositor commits |
+ // FrameView::setScrollOffset() doesn't work for compositor commits |
// (interacts poorly with programmatic scroll animations) so we need to use |
// the ScrollableArea version. The FrameView method should go away soon |
// anyway. |
- m_scrollableArea->ScrollableArea::setScrollPosition(newPosition, |
- CompositorScroll); |
+ m_scrollableArea->ScrollableArea::setScrollOffset(newOffset, |
+ CompositorScroll); |
} |
} |